==> mybb-1.4.10_1.tbz: www/mybb/inc/languages/english/portal.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright © 2008 MyBB Group, All Rights Reserved
 * 
 * $Id: portal.lang.php 4304 2009-01-02 01:11:56Z chris $
 */

$l['nav_portal'] = "Portal";
$l['posted_by'] = "Posted by:";
$l['replies'] = "Replies";
$l['no_replies'] = "No Replies";
$l['latest_threads'] = "Latest Threads";
$l['latest_threads_replies'] = "Replies:";
$l['latest_threads_views'] = "Views:";
$l['latest_threads_lastpost'] = "Last Post by:";
$l['private_messages'] = "Private Messages";
$l['pms_received_new'] = "{1}, you have <b>{2}</b> unread message(s).";
$l['pms_unread'] = "Unread Messages";
$l['pms_total'] = "Total Messages";
$l['search_forums'] = "Search Forums";
$l['advanced_search'] = "Advanced Search";
$l['forum_stats'] = "Forum Statistics";
$l['num_members'] = "Members:";
$l['latest_member'] = "Latest member:";
$l['num_threads'] = "Forum threads:";
$l['num_posts'] = "Forum posts:";
$l['full_stats'] = "Full Statistics";
$l['welcome'] = "Welcome, {1}";
$l['guest'] = "Guest";
$l['guest_welcome_registration'] = "You have to <a href=\"{1}\">register</a> before you can post on our site.";
$l['username'] = "Username";
$l['password'] = "Password";
$l['login'] = "Login!";
$l['member_welcome_lastvisit'] = "Last visit:";
$l['since_then'] = "Since then, there have been:";
$l['new_announcements'] = "{1} new announcements";
$l['new_announcement'] = "1 new announcement";
$l['new_threads'] = "{1} new threads";
$l['new_thread'] = "1 new thread";
$l['new_posts'] = "{1} new posts";
$l['new_post'] = "1 new post";
$l['view_new'] = "View New Posts";
$l['view_todays'] = "View Today's Posts";
$l['online'] = "Online Users";
$l['online_user'] = "There is currently 1 user online"; 
$l['online_users'] = "There are currently <b>{1}</b> online users.";
$l['online_counts'] = "<b>{1}</b> Member(s) | <b>{2}</b> Guest(s)";
$l['no_one'] = "no-one";
$l['print_this_item'] = "Print this item";
$l['send_to_friend'] = "Send this item to a friend";
?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/portal.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright 2010 MyBB Group, All Rights Reserved
 * 
 * $Id: portal.lang.php 5297 2010-12-28 22:01:14Z Tomm $
 */

$l['nav_portal'] = "Portal";
$l['posted_by'] = "Posted by:";
$l['replies'] = "Replies";
$l['no_replies'] = "No Replies";
$l['latest_threads'] = "Latest Threads";
$l['latest_threads_replies'] = "Replies:";
$l['latest_threads_views'] = "Views:";
$l['latest_threads_lastpost'] = "Last Post:";
$l['private_messages'] = "Private Messages";
$l['pms_received_new'] = "{1}, you have <b>{2}</b> unread message(s).";
$l['pms_unread'] = "Unread Messages";
$l['pms_total'] = "Total Messages";
$l['search_forums'] = "Search Forums";
$l['advanced_search'] = "Advanced Search";
$l['forum_stats'] = "Forum Statistics";
$l['num_members'] = "Members:";
$l['latest_member'] = "Latest member:";
$l['num_threads'] = "Forum threads:";
$l['num_posts'] = "Forum posts:";
$l['full_stats'] = "Full Statistics";
$l['welcome'] = "Welcome, {1}";
$l['guest'] = "Guest";
$l['guest_welcome_registration'] = "You have to <a href=\"{1}\">register</a> before you can post on our site.";
$l['username'] = "Username";
$l['password'] = "Password";
$l['login'] = "Login!";
$l['member_welcome_lastvisit'] = "Last visit:";
$l['since_then'] = "Since then, there have been:";
$l['new_announcements'] = "{1} new announcements";
$l['new_announcement'] = "1 new announcement";
$l['new_threads'] = "{1} new threads";
$l['new_thread'] = "1 new thread";
$l['new_posts'] = "{1} new posts";
$l['new_post'] = "1 new post";
$l['view_new'] = "View New Posts";
$l['view_todays'] = "View Today's Posts";
$l['online'] = "Online Users";
$l['online_user'] = "There is currently 1 user online"; 
$l['online_users'] = "There are currently <b>{1}</b> online users.";
$l['online_counts'] = "<b>{1}</b> Member(s) | <b>{2}</b> Guest(s)";
$l['no_one'] = "no-one";
$l['print_this_item'] = "Print this item";
$l['send_to_friend'] = "Send this item to a friend";
?>
